import pandas as pd
import numpy as np
import glob
import matplotlib.pyplot as plt
from sklearn import *



def convert():
    '''automatically read all the txt files present in currect working directory and convert to xlsx'''
    txts = glob.glob("*txt")
    for i in txts:
        x = pd.read_csv(i, sep="|")
        x.to_excel(i[:-3]+"xlsx")
        print("Success with ", i, "\nShape: ", x.shape, '\n')


def guess_name(name):
    '''automatically considers the desired file name from the provided hint'''
    li = glob.glob('*'+name+'*')
    if   len(li) == 0 : print('no such file')
    elif len(li) != 1 : print('Give more specific name-\n', li)
    else: file = li[0]; print(file); return file


def read_data(name, rows=5):
    '''automatically reads the desired file and returns as a pandas df from the provided name regex'''
    file = guess_name(name)
    if type(file) == str:
        endin = file[len(file)-4:][file[len(file)-4:].find('.')+1:]
        if endin=='pkl':
            a = pd.read_pickle(file)
            print(a.shape, display(a.head(rows)))
            return a
        elif endin =='csv':
            a = pd.read_csv(file, encoding='latin')
            print(a.shape, display(a.head(rows)))
            return a
        elif endin =='xlsx':
            a = pd.read_excel(file)
            print(a.shape, display(a.head(rows)))
            return a
        elif endin =='txt':
            a = pd.read_csv(file, sep = '|')
            print(a.shape, display(a.head(rows)))
            return a
        else:
            print(endin, 'type is yet not supported')




from distutils.core import setup

setup(

  name = 'istart',         # How you named your package folder (MyLib)

  packages = ['istart'],   # Chose the same as "name"

  version = '0.1',      # Start with a small number and increase it with every change you make

  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository

  description = 'Automate and simplify starting data science',   # Give a short description about your library

  author = 'Atulya Narayan',                   # Type in your name

  author_email = 'atulya.iims@gmail.com',      # Type in your E-Mail

  url = 'https://github.com/atulyanarayan/istart',   # Provide either the link to your github or to your website

  #download_url = 'https://github.com/user/reponame/archive/v_01.tar.gz',    # I explain this later on

  keywords = ['automate', 'simplify', 'intelligent data reading'],   # Keywords that define your package best

  install_requires=[            # I get to this in a second

          'pandas',

          'numpy','glob'

      ],

  classifiers=[

    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package

    'Intended Audience :: Developers',      # Define that your audience are developers

    'Topic :: Software Development :: Build Tools',

    'License :: OSI Approved :: MIT License',   # Again, pick a license

    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support

    'Programming Language :: Python :: 3.4',

    'Programming Language :: Python :: 3.5',

    'Programming Language :: Python :: 3.6',

  ],

)
